[−][src]Crate interledger_api
Structs
| AccountDetails | The Account type for the RedisStore. |
| AccountSettings | AccountSettings is a subset of the user parameters defined in AccountDetails. Its purpose is to allow a user to modify certain of their parameters which they may want to re-configure in the future, such as their tokens (which act as passwords), their settlement frequency preferences, or their HTTP/BTP endpoints, since they may change their network configuration. |
| NodeApi |
Traits
| NodeStore |