[][src]Struct interledger_api::AccountSettings

pub struct AccountSettings {
    pub http_incoming_token: Option<String>,
    pub btp_incoming_token: Option<String>,
    pub http_outgoing_token: Option<String>,
    pub btp_outgoing_token: Option<String>,
    pub http_endpoint: Option<String>,
    pub btp_uri: Option<String>,
    pub settle_threshold: Option<i64>,
    pub settle_to: Option<u64>,
}

AccountSettings is a subset of the user parameters defined in AccountDetails. Its purpose is to allow a user to modify certain of their parameters which they may want to re-configure in the future, such as their tokens (which act as passwords), their settlement frequency preferences, or their HTTP/BTP endpoints, since they may change their network configuration.

Fields

http_incoming_token: Option<String>btp_incoming_token: Option<String>http_outgoing_token: Option<String>btp_outgoing_token: Option<String>http_endpoint: Option<String>btp_uri: Option<String>settle_threshold: Option<i64>settle_to: Option<u64>